@@ -1,27 +1,10 @@
 #
 #  cdftest.R
 #
-#  $Revision: 2.15 $  $Date: 2017/01/18 07:58:44 $
+#  $Revision: 2.16 $  $Date: 2018/01/15 13:08:12 $
 #
 #
 
-# --------- old -------------
-
-ks.test.ppm <- function(...) {
-  .Deprecated("cdf.test.ppm", package="spatstat")
-  cdf.test.ppm(...)
-}
-
-kstest <- kstest.ppp <- kstest.ppm <- kstest.lpp <- kstest.lppm <-
-  kstest.slrm <-
-  function(...) {
-    message("kstest is out of date; use cdf.test")
-#  .Deprecated("cdf.test", package="spatstat")
-  cdf.test(..., test="ks")
-}
-
-# ---------------------------
-
 cdf.test <- function(...) {
   UseMethod("cdf.test")
 }
@@ -342,12 +325,6 @@ spatialCDFframe <- function(model, covariate, ...) {
   return(stuff)
 }
 
-plot.kstest <- function(x, ...) {
-  message("kstest is out of date; use cdf.test")
-#  .Deprecated("plot.cdftest", package="spatstat")
-  plot.cdftest(x, ...)
-}
-
 plot.cdftest <- function(x, ..., style=c("cdf", "PP", "QQ"),
                         lwd=par("lwd"), col=par("col"), lty=par("lty"),
                         lwd0=lwd, col0=2, lty0=2,
